@@ -2,8 +2,8 @@ use crate::az_impl::az_lmdb::LmdbAzContext;
 use crate::module::ticket::Ticket;
 use crate::onto::individual::Individual;
 use crate::onto::parser::parse_raw;
+use crate::storage::common::{Storage, StorageId};
 use crate::storage::lmdb_storage::LMDBStorage;
-use crate::storage::storage::{Storage, StorageId};
 use crate::v_api::obj::ResultCode;
 use crate::v_authorization::common::{Access, AuthorizationContext};
 use futures::lock::Mutex;
